define(
//begin v1.x content
({
	"descTemplate": "${1} 个${0}中的  ${2} - ${3}",
	"firstTip": "第一页",
	"lastTip": "最后一页",
	"nextTip": "下一页",
	"prevTip": "上一页",
	"itemTitle": "项目",
	"singularItemTitle": "项",
	"pageStepLabelTemplate": "第 ${0} 页",
	"pageSizeLabelTemplate": "每页的 ${0} 项目",
	"allItemsLabelTemplate": "所有项目",
	"gotoButtonTitle": "转到指定页面",
	"dialogTitle": "转到页面",
	"dialogIndication": "指定页数",
	"pageCountIndication": "（${0} 页）",
	"dialogConfirm": "确定",
	"dialogCancel": "取消",
	"all": "全部"
})
//end v1.x content
);

